--- str_version.c 2001/09/13 14:12:58 1.13
+++ str_version.c 2002/04/01 08:32:55 1.14
@@ -1,5 +1,5 @@
/*
** str_version.c -- Version Information for Str (syntax: C/C++)
** [automatically generated and maintained by GNU shtool]
*/
@@ -8,7 +8,7 @@
#ifndef _STR_VERSION_C_
#define _STR_VERSION_C_
-#define STR_VERSION 0x009206
+#define STR_VERSION 0x009207
typedef struct {
const int v_hex;
@@ -32,14 +32,14 @@
#undef _STR_VERSION_C_AS_HEADER_
str_version_t str_version = {
- 0x009206,
- "0.9.6",
- "0.9.6 (13-Sep-2001)",
- "This is Str, Version 0.9.6 (13-Sep-2001)",
- "Str 0.9.6 (13-Sep-2001)",
- "Str/0.9.6",
- "@(#)Str 0.9.6 (13-Sep-2001)",
- "$Id: Str 0.9.6 (13-Sep-2001) $"
+ 0x009207,
+ "0.9.7",
+ "0.9.7 (01-Apr-2002)",
+ "This is OSSP str, Version 0.9.7 (01-Apr-2002)",
+ "OSSP str 0.9.7 (01-Apr-2002)",
+ "OSSP str/0.9.7",
+ "@(#)OSSP str 0.9.7 (01-Apr-2002)",
+ "$Id: OSSP str 0.9.7 (01-Apr-2002) $"
};
#endif /* _STR_VERSION_C_AS_HEADER_ */
|
@@ -1,5 +1,5 @@
/*
-** str_version.c -- Version Information for Str (syntax: C/C++)
+** str_version.c -- Version Information for OSSP str (syntax: C/C++)
** [automatically generated and maintained by GNU shtool]
*/